@@ -1,9 +1,11 @@
 import os, logging
 import fnmatch, re
 
+from puke.Console import *
+
 class FileList:
 
-	def __init__(self, dir, filter = "", exclude = ""):
+	def __init__(self, dir, filter = "*", exclude = ""):
 		self.__list = []
 		self.__dir = dir
 		self.__filter = ""
@@ -55,5 +57,11 @@ class FileList:
 	        if os.path.isdir(nfile):
 	            self.__explore(nfile)
 	        elif self.__filter.match(nfile) and not self.__exclude.match(nfile):
+	        	tmp = nfile.split(self.__dir)
+	        	if len(tmp) > 1:
+	        		nfile = self.__dir + tmp[1]
+	        	else:
+	        		nfile = tmp[0]
+	        	
 	        	self.__list.append(nfile)
 	        
\ No newline at end of file
