@@ -155,7 +155,7 @@ def makedir(dirname):
     if not os.path.exists(dirname):
         os.makedirs(dirname)
 
-def deepcopy(file_list, folder):
+def deepcopy(file_list, folder, replace = None):
 
     if isinstance(file_list, FileList):
         file_list = file_list.get()
@@ -168,6 +168,18 @@ def deepcopy(file_list, folder):
         dst_file = os.path.join(folder,os.path.basename(file))
         res = updatefile(file, dst_file)
 
+
+        if replace:
+            fh = open(dst_file)
+            data = fh.read() + '\n'
+        
+            for k in replace.keys():
+                data = data.replace(k, replace.get(k))
+
+            fh.close()
+            writefile(dst_file, data)
+
+
         if res:
             console.info(' + %s' % file)
             stat += 1
